
From: Matt Mackall <mpm@selenic.com>

Remove PAGE_BUG - repalce it with BUG and BUG_ON.

Signed-off-by: Matt Mackall <mpm@selenic.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/arm26/mm/small_page.c |    6 ++----
 25-akpm/fs/afs/file.c              |    3 +--
 25-akpm/fs/buffer.c                |    3 +--
 25-akpm/fs/jffs2/file.c            |    3 +--
 25-akpm/fs/udf/file.c              |    6 ++----
 25-akpm/fs/udf/inode.c             |    4 ++--
 25-akpm/include/asm-cris/page.h    |    4 ----
 25-akpm/include/asm-generic/bug.h  |   11 -----------
 25-akpm/include/asm-sh64/bug.h     |    4 ----
 25-akpm/mm/filemap.c               |    3 +--
 10 files changed, 10 insertions(+), 37 deletions(-)

diff -puN arch/arm26/mm/small_page.c~exterminate-page_bug arch/arm26/mm/small_page.c
--- 25/arch/arm26/mm/small_page.c~exterminate-page_bug	Fri Apr  1 13:55:05 2005
+++ 25-akpm/arch/arm26/mm/small_page.c	Fri Apr  1 13:55:06 2005
@@ -92,8 +92,7 @@ static unsigned long __get_small_page(in
 		page = list_entry(order->queue.next, struct page, lru);
 again:
 #ifdef PEDANTIC
-		if (USED_MAP(page) & ~order->all_used)
-			PAGE_BUG(page);
+		BUG_ON(USED_MAP(page) & ~order->all_used);
 #endif
 		offset = ffz(USED_MAP(page));
 		SET_USED(page, offset);
@@ -141,8 +140,7 @@ static void __free_small_page(unsigned l
 			goto non_small;
 
 #ifdef PEDANTIC
-		if (USED_MAP(page) & ~order->all_used)
-			PAGE_BUG(page);
+		BUG_ON(USED_MAP(page) & ~order->all_used);
 #endif
 
 		spage = spage >> order->shift;
diff -puN fs/afs/file.c~exterminate-page_bug fs/afs/file.c
--- 25/fs/afs/file.c~exterminate-page_bug	Fri Apr  1 13:55:05 2005
+++ 25-akpm/fs/afs/file.c	Fri Apr  1 13:55:06 2005
@@ -131,8 +131,7 @@ static int afs_file_readpage(struct file
 
 	vnode = AFS_FS_I(inode);
 
-	if (!PageLocked(page))
-		PAGE_BUG(page);
+	BUG_ON(!PageLocked(page));
 
 	ret = -ESTALE;
 	if (vnode->flags & AFS_VNODE_DELETED)
diff -puN fs/buffer.c~exterminate-page_bug fs/buffer.c
--- 25/fs/buffer.c~exterminate-page_bug	Fri Apr  1 13:55:05 2005
+++ 25-akpm/fs/buffer.c	Fri Apr  1 13:55:06 2005
@@ -2078,8 +2078,7 @@ int block_read_full_page(struct page *pa
 	int nr, i;
 	int fully_mapped = 1;
 
-	if (!PageLocked(page))
-		PAGE_BUG(page);
+	BUG_ON(!PageLocked(page));
 	blocksize = 1 << inode->i_blkbits;
 	if (!page_has_buffers(page))
 		create_empty_buffers(page, blocksize, 0);
diff -puN fs/jffs2/file.c~exterminate-page_bug fs/jffs2/file.c
--- 25/fs/jffs2/file.c~exterminate-page_bug	Fri Apr  1 13:55:05 2005
+++ 25-akpm/fs/jffs2/file.c	Fri Apr  1 13:55:06 2005
@@ -79,8 +79,7 @@ static int jffs2_do_readpage_nolock (str
 
 	D2(printk(KERN_DEBUG "jffs2_do_readpage_nolock(): ino #%lu, page at offset 0x%lx\n", inode->i_ino, pg->index << PAGE_CACHE_SHIFT));
 
-	if (!PageLocked(pg))
-                PAGE_BUG(pg);
+	BUG_ON(!PageLocked(pg));
 
 	pg_buf = kmap(pg);
 	/* FIXME: Can kmap fail? */
diff -puN fs/udf/file.c~exterminate-page_bug fs/udf/file.c
--- 25/fs/udf/file.c~exterminate-page_bug	Fri Apr  1 13:55:06 2005
+++ 25-akpm/fs/udf/file.c	Fri Apr  1 13:55:06 2005
@@ -49,8 +49,7 @@ static int udf_adinicb_readpage(struct f
 	struct inode *inode = page->mapping->host;
 	char *kaddr;
 
-	if (!PageLocked(page))
-		PAGE_BUG(page);
+	BUG_ON(!PageLocked(page));
 
 	kaddr = kmap(page);
 	memset(kaddr, 0, PAGE_CACHE_SIZE);
@@ -67,8 +66,7 @@ static int udf_adinicb_writepage(struct 
 	struct inode *inode = page->mapping->host;
 	char *kaddr;
 
-	if (!PageLocked(page))
-		PAGE_BUG(page);
+	BUG_ON(!PageLocked(page));
 
 	kaddr = kmap(page);
 	memcpy(UDF_I_DATA(inode) + UDF_I_LENEATTR(inode), kaddr, inode->i_size);
diff -puN fs/udf/inode.c~exterminate-page_bug fs/udf/inode.c
--- 25/fs/udf/inode.c~exterminate-page_bug	Fri Apr  1 13:55:06 2005
+++ 25-akpm/fs/udf/inode.c	Fri Apr  1 13:55:06 2005
@@ -167,8 +167,8 @@ void udf_expand_file_adinicb(struct inod
 	}
 
 	page = grab_cache_page(inode->i_mapping, 0);
-	if (!PageLocked(page))
-		PAGE_BUG(page);
+	BUG_ON(!PageLocked(page));
+
 	if (!PageUptodate(page))
 	{
 		kaddr = kmap(page);
diff -puN include/asm-cris/page.h~exterminate-page_bug include/asm-cris/page.h
--- 25/include/asm-cris/page.h~exterminate-page_bug	Fri Apr  1 13:55:06 2005
+++ 25-akpm/include/asm-cris/page.h	Fri Apr  1 13:55:06 2005
@@ -77,10 +77,6 @@ typedef struct { unsigned long pgprot; }
   printk("kernel BUG at %s:%d!\n", __FILE__, __LINE__); \
 } while (0)
 
-#define PAGE_BUG(page) do { \
-         BUG(); \
-} while (0)
-
 /* Pure 2^n version of get_order */
 static inline int get_order(unsigned long size)
 {
diff -puN include/asm-generic/bug.h~exterminate-page_bug include/asm-generic/bug.h
--- 25/include/asm-generic/bug.h~exterminate-page_bug	Fri Apr  1 13:55:06 2005
+++ 25-akpm/include/asm-generic/bug.h	Fri Apr  1 13:55:06 2005
@@ -12,13 +12,6 @@
 } while (0)
 #endif
 
-#ifndef HAVE_ARCH_PAGE_BUG
-#define PAGE_BUG(page) do { \
-	printk("page BUG for page at %p\n", page); \
-	BUG(); \
-} while (0)
-#endif
-
 #ifndef HAVE_ARCH_BUG_ON
 #define BUG_ON(condition) do { if (unlikely((condition)!=0)) BUG(); } while(0)
 #endif
@@ -37,10 +30,6 @@
 #define BUG()
 #endif
 
-#ifndef HAVE_ARCH_PAGE_BUG
-#define PAGE_BUG(page) do { if (page) ; } while (0)
-#endif
-
 #ifndef HAVE_ARCH_BUG_ON
 #define BUG_ON(condition) do { if (condition) ; } while(0)
 #endif
diff -puN include/asm-sh64/bug.h~exterminate-page_bug include/asm-sh64/bug.h
--- 25/include/asm-sh64/bug.h~exterminate-page_bug	Fri Apr  1 13:55:06 2005
+++ 25-akpm/include/asm-sh64/bug.h	Fri Apr  1 13:55:06 2005
@@ -17,10 +17,6 @@
 		BUG(); \
 } while(0)
 
-#define PAGE_BUG(page) do { \
-	BUG(); \
-} while (0)
-
 #define WARN_ON(condition) do { \
 	if (unlikely((condition)!=0)) { \
 		printk("Badness in %s at %s:%d\n", __FUNCTION__, __FILE__, __LINE__); \
diff -puN mm/filemap.c~exterminate-page_bug mm/filemap.c
--- 25/mm/filemap.c~exterminate-page_bug	Fri Apr  1 13:55:06 2005
+++ 25-akpm/mm/filemap.c	Fri Apr  1 13:55:06 2005
@@ -123,8 +123,7 @@ void remove_from_page_cache(struct page 
 {
 	struct address_space *mapping = page->mapping;
 
-	if (unlikely(!PageLocked(page)))
-		PAGE_BUG(page);
+	BUG_ON(!PageLocked(page));
 
 	write_lock_irq(&mapping->tree_lock);
 	__remove_from_page_cache(page);
_
